from .dynamic_element import DynamicElement

console_element = str | DynamicElement
line_type = str | list[console_element]